#include <stdio.h>
#include <assert.h>
#include <string>
#include <unordered_set>
#include <unordered_map>
#include <algorithm>

#define MAXN 10000
#define MAXW 10

using namespace std;

char W[MAXN][MAXW+1];
char P[MAXN+1];
int N, K, L, A, B, i;

unordered_set<string> avoid, respect;
unordered_map<string, int> attempt;

// given a so-far valid password P,
// returns an optimistic estimate of the longest following valid sequence
// which is L only if a winning sequence is found (and stored in P)
int fabricate(int X) {
    if (X == L) return L;
    // compute optimistic bound using saved information
    int R = L;
    for (int b=1; b<=min(B-1,X); ++b)
        if ( attempt.count(P + (X-b)) )
            R = min(R, X+attempt[P + (X-b)]);
    // if R<L, no way we can produce a valid sequence
    if (R < L) return R;
    // otherwise, we can try to proceed
    R = X;
    for (char c = 'a'; c <= 'z'; ++c) {
        P[X] = c;
        P[X+1] = 0;
        // if it is not consistent or novel, skip to next char
        if ( not respect.count(P + max(X+1-A,0)) ) continue;
        if ( X+1 >= B and avoid.count(P + (X+1-B)) ) continue;
        // otherwise, proceed recursively
        R = max(R, fabricate(X+1));
        if (R == L) return L;
    }
    // if no valid completion is found, store the longest completion found
    P[X] = 0;
    string s(P);
    attempt[s.substr(max(0, (int)s.size()-B+1))] = R-X;
    return R;
}

int main() {
    FILE *fr, *fw;

#ifdef EVAL
    fr = fopen("input.txt", "r");
    fw = fopen("output.txt", "w");
#else
    fr = stdin;
    fw = stdout;
#endif
    assert(3 == fscanf(fr, "%d %d %d", &N, &K, &L));
    A = K;
    B = K+1;
    for(i=0; i<N; i++) {
        assert(1 == fscanf(fr, "%s", W[i]));
        string s(W[i]);
        for (int a=1; a<=A; ++a)
            for (int j=0; j<=(int)s.size()-a; ++j) respect.insert(s.substr(j, a));
        for (int j=0; j<=(int)s.size()-B; ++j) avoid.insert(s.substr(j, B));
    }

    if (fabricate(0)) fprintf(fw, "%s\n", P);
    // the number of entries in the table is bounded by the total length of the words times K
    assert(attempt.size() <= N*A*MAXW);
    fclose(fr);
    fclose(fw);
    return 0;
}
