#include <stdio.h>
#include <assert.h>

#define MAXN 1000000

// MODIFIED EUCLIDE-BEZOUT ALGORITHM
// computes the GCD and h,k such that a*k + b*h == N and h>=0 is minimum
void euclide_bezout(long long a, long long b, long long N, long long& GCD, long long& k, long long& h) {
    if (b == 0) {
        if (N % a > 0) { // the problem is unsolvable
            GCD = -1;
            return;
        }
        GCD = a;
        k = N/a;
        h = 0;
        return;
    }
    euclide_bezout(b, a % b, N, GCD, h, k);
    if (a < b or GCD == -1) return;
    h -= k * (a/b); // makes coefficients work for a, b
    // reduces h as much as possible
    long long x = h >= 0 ? h / (a/GCD) : -1-((-h-1) / (a/GCD));
    k += x * (b/GCD);
    h -= x * (a/GCD);
    // checks correctness
    assert(0 <= h and h < a/GCD);
    assert(k * a + h * b == N);
}

int guess(int N, int M, int D, int S[]) {
    int E = 1;
    for (int d=0; d<D; ++d) E *= 10;
    int sum = 0;
    for (int i=0; i<N; ++i) sum += S[i];
    if (sum == 0) return 0;
    for (int K=1; ; ++K) {
        long long A = 0, GCD, a, b, EG;
        for (int i=0; i<N; ++i) {
            euclide_bezout(E, K, S[i], GCD, b, a);
            EG = E / GCD;
            if (GCD == -1) A = M+1;
            // adjust a to be above A
            else A = a + ((A-a+EG)/EG) * EG;
            if (A > M) break;
        }
        if (A <= M) return K;
    }
}


int S[MAXN];

int main() {
    FILE *fr, *fw;
    int N, M, D, i;

#ifdef EVAL
    fr = fopen("input.txt", "r");
    fw = fopen("output.txt", "w");
#else
    fr = stdin;
    fw = stdout;
#endif
    assert(3 == fscanf(fr, "%d %d %d", &N, &M, &D));
    for(i=0; i<N; i++)
        assert(1 == fscanf(fr, "%d", &S[i]));

    fprintf(fw, "%d\n", guess(N, M, D, S));
    fclose(fr);
    fclose(fw);
    return 0;
}
